(function () {
	'use strict';

	var dep = "default";

	var dep$1 = /*#__PURE__*/Object.freeze({
		__proto__: null,
		default: dep
	});

	console.log(dep$1);

})();
